identify = ["identify"]
email = ["email"]
connections = ["connections"]
guilds = ["guilds"]
guilds_join = ["guilds.join"]
guilds_members_read = ["guilds.members.read"]
gdm_join = ["gdm.join"]
rpc = ["rpc"]
rpc_notifications_read = ["rpc.notifications.read"]
rpc_voice_read = ["rpc.voice.read"]
rpc_voice_write = ["rpc.voice.write"]
rpc_activities_write = ["rpc.activities.write"]
bot = ["bot"] 
webhook_incoming = ["webhook.incoming"] 
messages_read = ["messages.read"] 
applications_builds_upload = ["applications.builds.upload"] 
applications_builds_read = ["applications.builds.read"] 
applications_commands = ["applications.commands"] 
applications_store_update = ["applications.store.update"] 
applications_entitlements = ["applications.entitlements"] 
activities_read = ["activities.read"] 
activities_write = ["activities.write"] 
relationships_read = ["relationships.read"] 
voice = ["voice"]
dm_channels_read = ["dm_channels.read"]
role_connections_write = ["role_connections.write"]
applications_commands_permissions_update = ["applications.commands.permissions.update"]

none = []
basic = identify + guilds
invite_bot = bot + applications_commands
all = identify + email + connections + guilds + guilds_join + guilds_members_read + gdm_join + rpc + rpc_notifications_read + rpc_voice_read + rpc_voice_write + rpc_activities_write + bot + webhook_incoming + messages_read + applications_builds_upload + applications_builds_read + applications_commands + applications_store_update + applications_entitlements + activities_read + activities_write + relationships_read + voice + dm_channels_read + role_connections_write + applications_commands_permissions_update



from flascord import scope
from flask import request, session, redirect, current_app
import requests

class DiscordOauth2Session:
    def __init__(self, app):
        self.app = app
        self.scope = []
        self.config = self.app.config
        self.base_url = 'https://discord.com/api/v9'
        self.oauth_url = self.base_url + '/oauth2/'
        self.get_token_url = self.oauth_url + '/token'

    def login(self,scope=scope.basic):
        self.scope = scope
        scope = '%20'.join(scope)
        login_url = f"{self.oauth_url}authorize?client_id={self.config['DISCORD_CLIENT_ID']}&redirect_uri={self.config['DISCORD_REDIRECT_URI']}&response_type=code&scope={scope}"
        return redirect(login_url)

    def callback(self):
        try:
            authorization_code = request.args.get("code")
        except:
            error_code = request.args.get("error")
        else:
            request_postdata = {'client_id': self.config['DISCORD_CLIENT_ID'], 'client_secret': self.config['DISCORD_CLIENT_SECRET'], 'grant_type': 'authorization_code', 'code': authorization_code, 'redirect_uri': self.config['DISCORD_REDIRECT_URI']}
            accesstoken_request = requests.post(url=self.get_token_url, data=request_postdata)

            responce_json = accesstoken_request.json()

            session['access_token'] = responce_json['access_token']
            session['token_type'] = responce_json['token_type']
            session['expires_in'] = responce_json['expires_in']
            session['refresh_token'] = responce_json['refresh_token']
            session['scope'] = responce_json['scope']     
        return

    def refresh(self):
        data = {'client_id': self.config['DISCORD_CLIENT_ID'], 'client_secret': self.config['DISCORD_CLIENT_SECRET'], 'grant_type': 'refresh_token', 'refresh_token': session['refresh_token']}
        accesstoken_request = requests.post(url=self.get_token_url, data=data)
        responce_json = accesstoken_request.json()
        session['access_token'] = responce_json['access_token']
        session['token_type'] = responce_json['token_type']
        session['expires_in'] = responce_json['expires_in']
        session['refresh_token'] = responce_json['refresh_token']
        session['scope'] = responce_json['scope']     
        return



from setuptools import setup, Extension, find_packages
import os

VERSION = '0.1.1'

def load_requires_from_file():
    with open('requirements.txt') as f:
        requirements = f.read().splitlines()
    return requirements

def load_readme_from_file():
    with open('README.md', 'r', encoding='utf-8') as fp:
        readme = fp.read()
    return readme

setup(
    name='Flascord',
    author='Yorukaze LURU',
    license='MIT',
    url="https://github.com/yorukaze-luru/Flascord",
    version=VERSION,
    packages=find_packages(),
    include_package_data=True,
    KEYWORDS = 'flask discord oauth2',
    long_description=load_readme_from_file(),
    long_description_content_type='text/markdown',
    CLASSIFIERS=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    install_requires=load_requires_from_file(),
)
